# onepassword_secrets_backend
Custom 1password secrets backend for airflow. Intended to store connections/variables/configs in 1password vaults.

Secrets should be stored in 1password as a plain note text!
